@@ -15,15 +15,7 @@ def html_init(name):
     :type name : str
     :return: html_init as str
     """
-    result = ""
-    result += "<html>\n"
-    result += "<head>\n"
-    result += "<title>" + str(name) + "</title>\n"
-    result += "</head>\n"
-    result += "<body>\n"
-    result += '<h1 style="border-bottom:1px solid ' \
-              'black;text-align:center;">PyCM Report</h1>'
-    return result
+    return HTML_INIT_TEMPLATE.format(str(name), OG_DESCRIPTION, OG_IMAGE_URL)
 
 
 def html_dataset_type(is_binary, is_imbalanced):
@@ -43,7 +35,7 @@ def html_dataset_type(is_binary, is_imbalanced):
         balance_type = "Imbalanced"
     if not is_binary:
         class_type = "Multi-Class Classification"
-    result += "<ul>\n\n<li>{0}</li>\n\n<li>{1}</li>\n</ul>\n".format(
+    result += "<ul>\n<li>{0}</li>\n<li>{1}</li>\n</ul>\n".format(
         class_type, balance_type)
     result += "<p>{0}</p>\n".format(RECOMMEND_HTML_MESSAGE)
     result += "<p>{0}</p>\n".format(RECOMMEND_HTML_MESSAGE2)
@@ -113,14 +105,14 @@ def html_table(classes, table, rgb_color, normalize=False):
         result += "(Normalized)"
     result += ": </h2>\n"
     result += '<table>\n'
-    result += '<tr  align="center">' + "\n"
+    result += '<tr style="text-align:center;">' + "\n"
     result += '<td>Actual</td>\n'
     result += '<td>Predict\n'
     table_size = str((len(classes) + 1) * 7) + "em"
     result += '<table style="border:1px solid black;border-collapse: collapse;height:{0};width:{0};">\n'\
         .format(table_size)
     classes.sort()
-    result += '<tr align="center">\n<td></td>\n'
+    result += '<tr style="text-align:center;">\n<td></td>\n'
     part_2 = ""
     for i in classes:
         class_name = str(i)
@@ -129,7 +121,7 @@ def html_table(classes, table, rgb_color, normalize=False):
         result += '<td style="border:1px solid ' \
                   'black;padding:10px;height:7em;width:7em;">' + \
             class_name + '</td>\n'
-        part_2 += '<tr align="center">\n'
+        part_2 += '<tr style="text-align:center;">\n'
         part_2 += '<td style="border:1px solid ' \
                   'black;padding:10px;height:7em;width:7em;">' + \
             class_name + '</td>\n'
@@ -139,7 +131,7 @@ def html_table(classes, table, rgb_color, normalize=False):
             back_color = html_table_color(table[i], item, rgb_color)
             if min(back_color) < 128:
                 color = "white"
-            part_2 += '<td style="background-color:	rgb({0},{1},{2});color:{3};padding:10px;height:7em;width:7em;">'.format(
+            part_2 += '<td style="background-color:rgb({0},{1},{2});color:{3};padding:10px;height:7em;width:7em;">'.format(
                 str(back_color[0]), str(back_color[1]), str(back_color[2]), color) + str(item) + '</td>\n'
         part_2 += "</tr>\n"
     result += '</tr>\n'
@@ -185,7 +177,7 @@ def html_overall_stat(
         background_color = DEFAULT_BACKGROUND_COLOR
         if i in recommended_list:
             background_color = RECOMMEND_BACKGROUND_COLOR
-        result += '<tr align="center">\n'
+        result += '<tr style="text-align:center;">\n'
         result += '<td style="border:1px solid black;padding:4px;text-align:left;background-color:{};"><a href="'.format(
             background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
         if i in BENCHMARK_LIST:
@@ -230,7 +222,7 @@ def html_class_stat(
     result = ""
     result += "<h2>Class Statistics : </h2>\n"
     result += '<table style="border:1px solid black;border-collapse: collapse;">\n'
-    result += '<tr align="center">\n<td>Class</td>\n'
+    result += '<tr style="text-align:center;">\n<td>Class</td>\n'
     for i in classes:
         result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;">' + \
             str(i) + '</td>\n'
@@ -247,7 +239,7 @@ def html_class_stat(
         background_color = DEFAULT_BACKGROUND_COLOR
         if i in recommended_list:
             background_color = RECOMMEND_BACKGROUND_COLOR
-        result += '<tr align="center" style="border:1px solid black;border-collapse: collapse;">\n'
+        result += '<tr style="text-align:center;border:1px solid black;border-collapse: collapse;">\n'
         result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;background-color:{};"><a href="'.format(
             background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
         for j in classes:
@@ -276,12 +268,7 @@ def html_end(version):
     :type version:str
     :return: html_end as str
     """
-    result = "</body>\n"
-    result += '<p style="text-align:center;border-top:1px solid black;">Generated By ' \
-        '<a href="http://www.pycm.ir" ' \
-              'style="text-decoration:none;color:red;">PyCM</a> Version ' + version + '</p>\n'
-    result += "</html>"
-    return result
+    return HTML_END_TEMPLATE.format(version)
 
 
 def pycm_help():
